Trait toml_query::read::TomlValueReadExt
[−]
[src]
pub trait TomlValueReadExt<'doc> {
fn read_with_seperator(
&'doc self,
query: &str,
sep: char
) -> Result<Option<&'doc Value>>;
fn read_mut_with_seperator(
&'doc mut self,
query: &str,
sep: char
) -> Result<Option<&'doc mut Value>>;
fn read(&'doc self, query: &str) -> Result<Option<&'doc Value>> { ... }
fn read_mut(&'doc mut self, query: &str) -> Result<Option<&'doc mut Value>> { ... }
}
Required Methods
fn read_with_seperator(
&'doc self,
query: &str,
sep: char
) -> Result<Option<&'doc Value>>
&'doc self,
query: &str,
sep: char
) -> Result<Option<&'doc Value>>
Extension function for reading a value from the current toml::Value document using a custom seperator
fn read_mut_with_seperator(
&'doc mut self,
query: &str,
sep: char
) -> Result<Option<&'doc mut Value>>
&'doc mut self,
query: &str,
sep: char
) -> Result<Option<&'doc mut Value>>
Extension function for reading a value from the current toml::Value document mutably using a custom seperator
Provided Methods
fn read(&'doc self, query: &str) -> Result<Option<&'doc Value>>
Extension function for reading a value from the current toml::Value document
fn read_mut(&'doc mut self, query: &str) -> Result<Option<&'doc mut Value>>
Extension function for reading a value from the current toml::Value document mutably
Implementors
impl<'doc> TomlValueReadExt<'doc> for Value